%{

/* diacu.ll
 * lex file for converting Ascii German into diacritical German;
 * this program generates umlaut characters, but NO sharp s!
 */
%}

%p 6500
%n 2000
%e 2500
%a 4000
%k 2500
%o 3500


V	[AEIOUaeiou]
C	[B-DF-HJ-NP-TV-Zb-df-hj-np-tv-z]
W	[ "'\t\n,;!?().-]
b       [ \t\n]

%%

\\begin\{.+\}	ECHO;
\\end\{.+\}	ECHO;
\\[A-Za-z]+	ECHO;

Ghana      ECHO;
Jena       ECHO;
Fulda      ECHO;
Riga       ECHO;
Kairo      ECHO;
Nizza      ECHO;
Lueger/[^e] ECHO;
Goebbels   ECHO;
AEG        ECHO;
UEFA       ECHO;
OECD       ECHO;
IAE[AO]    ECHO;
outine     ECHO;
ilanz      ECHO;
Oetker     ECHO;
Gevaert    ECHO;
Uerding    ECHO;
Hoechst-   ECHO;
{W}goes/{W} ECHO;

Venlo      ECHO;
Tokio      ECHO;
[glmnrt]ae/{W}    ECHO;
[hdfsrZ]oe/{W}    ECHO;  /* McEnroe Monroe */
[bcdghloRrStv]ue/{W} ECHO;  /* blue, Virtue, getue, Purdue, Overdue, Residue */


       [Ii]ssue            ECHO;
    [Cc]ontinue            ECHO;
         [Qq]ueue          ECHO;
         [Gg]uest          ECHO;
       [Vv]alue            ECHO;
           true/{W}        ECHO;
           ware            ECHO;
        [Rr]euessier       printf("%cessier", yytext[0]);


         [Bb]u[ea]nos	   ECHO;
         [Dd]uett	   ECHO;
      [Ff]ondue	           ECHO;
     [Rr]esiduen	   ECHO;
   [Ii]ndividuen	   ECHO;
         [Dd]uell	   ECHO;
            Buer/{W}       ECHO;
         [Bb]uero          printf("%cro",yytext[0]);
       [Ss]aeuer           printf("%cuer",yytext[0]);
        [Bb]lues[^c]  	   ECHO;
      [Aa]ffluen	   ECHO;
      [Ii]nfluen	   ECHO;
     [Kk]onfluen	   ECHO;
            Fuerteventura  ECHO;
         [Gg]uerill	   ECHO;
            Guerni[kc]a    ECHO;
           Thue/{W}        ECHO;
      [Ll]eague		   ECHO;
      [Aa]biguen	   ECHO;
      dr[io]gue            ECHO;
       [Mm]igue[tl]	   ECHO;
   [Mm][ao]rgue 	   ECHO;
         longue[^r] 	   ECHO;
            Guevara        ECHO;
       [Ss]amuel	   ECHO;
       [Mm]anuel	   ECHO;
       [Aa]nnuell	   ECHO;
       [Mm]enuett	   ECHO;
      [Aa]venue 	   ECHO;
     [Rr]evenue 	   ECHO;
      [Pp]irouett	   ECHO;
     [Ss]ilhouett[ei]	   ECHO;
         [Pp]uert[ao]	   ECHO;
         [Pp]uebl[ao]	   ECHO;
         [Pp]ueril	   ECHO;
     [Kk]ongruen	   ECHO;
         [Ss]uez	   ECHO;

      {W}[Tt]ue/{W}        ECHO;
       [^sS]tuend	   ECHO;
            tuendere	   ECHO;
      [Ss]tatue	           ECHO;
       Gummituell          printf("Gummitll");
           ituell	   ECHO;
           ituen	   ECHO;
          ensuell	   ECHO;
       [Vv]isuell	   ECHO;
        [Uu]suell	   ECHO;
          entuell 	   ECHO;
         zeptuell          ECHO;
       [krx]tuell	   ECHO;
      ichtigtue[nr]        ECHO;
 [Hh]eimlichtue[nr]        ECHO;
   [Ss]choentue[nr]        printf("%cchntue%c",yytext[0],yytext[9]);
   [Nn]ichtstue[nr]        ECHO;
        rosstue[nr]        ECHO;
         [Tt]uerei/{W}     ECHO;
      {W}[Tt]uet/{W}       ECHO;
       [a-z]tuerei         ECHO;
       [a-z]tuerisch       ECHO;
       [Rrl]evue           ECHO;
       [Ss]exuell	   ECHO;


         [Zz]uein	   ECHO;
            zuent	   ECHO;
            zuerfind       ECHO;
            zuerhalt       ECHO;
         [Zz]uerkannt	   ECHO;
         [Zz]uerkenn	   ECHO;
            zuerleg        ECHO;
         [Zz]uerteil	   ECHO;
         [Zz]uerst	   ECHO;
         [Zz]uerwerb       ECHO;
            zuerz	   ECHO;
            zuessen        ECHO;

       [Aa]bzue[^g]        ECHO;
    [Rr]ueckzu             printf("%cckzu",yytext[0]);
       [Aa]nzue[^gnc]      ECHO;
      [Ee]inzu             ECHO;
      [Hh]inzu             ECHO;
   [Ww]iederzu             ECHO;
      [Vv]orzue[^g]        ECHO;
      [Mm]itzu             ECHO;

--       [Zz]ue[b-z][a-z]+[elr]n	ECHO;
--     [Aa]bzue[b-z][a-z]*[elr]n	ECHO;
--   [Nn]achzue[b-z][a-z]*[elr]n	ECHO;
--[Aa]nzue[b-z][a-z]*[elr]n	ECHO;
--[Ee]inzue[b-z][a-z]*[elr]n	ECHO;
--[Hh]inzue[b-z][a-z]*[elr]n	ECHO;
--[Aa]u[fs]zue[b-z][a-z]*[elr]n	ECHO;
--[Ww]iederzue[b-z][a-z]*[elr]n	ECHO;
--[Vv]orzue[b-z][a-z]*[elr]n	ECHO;
--[Mm]itzue[b-z][a-z]*[elr]n	ECHO;

      [Vv]enezuel	   ECHO;


           aeue         printf("ue");  
           Aeue         printf("ue");  
 [^igGbB][Ee]ue         ECHO;
       [QqAa]ue         ECHO;
          [Uu]e[iu]     ECHO;


       [Ss]phaero	printf("%cphro",yytext[0]);
      [^t][Aa]ero	ECHO;
       [Ss]o[df]a       ECHO;
             aeuel      printf("uel");
            Baedeker    ECHO;
       [Rr]afael	ECHO;
    [Ss]traf            ECHO;
      [Rr]affael	ECHO;
      [Mm]ichael	ECHO;
      [Rr]aphael	ECHO;
     ypermedia          ECHO;
     [Dd]odekae	        ECHO;
      [Kk]afkaesk	ECHO;
         [Mm]aestro     ECHO;
     [Ss]chemae	        ECHO;
      [Tt]hemae	        ECHO;
     [Pp]harmae	        ECHO;
            Paella      ECHO;
        [Pp]raerog	printf("%crrog",yytext[0]);
       [Ii]srael	ECHO;
      [Tt]etrae	        ECHO;
      [Ii]kosae	        ECHO;
       [Mm]etae	        ECHO;
      [Pp]entae	        ECHO;
     [Oo][kc]tae        ECHO;
       [Hh]exae	        ECHO;




      [Tt]urbo	        ECHO;
     [Pp]seudo 	        ECHO;
      [Vv]ideo	        ECHO;
         [ck]ago        ECHO;
       [Ee]cho  	ECHO;
     [Pp]sycho  	ECHO;
     [Pp]hysio  	ECHO;
      [Rr]adio 	        ECHO;
       [Mm]ono  	ECHO;
      [Cc]hemo/[^e][^g][^l]	        ECHO;
     [Tt]hermo  	ECHO;
       [Kk]ino  	ECHO;
      [Hh]ydro  	ECHO;
         Citro          ECHO;
    [Ee]lektro	        ECHO;
      [Nn]euro  	ECHO;
       [Pp]yro 	        ECHO;
       [Oo]kto 	        ECHO;
      [Kk]onto  	ECHO;
      [Pp]hoto  	ECHO;
      [Pp]roto	        ECHO;
       [Oo]pto 	        ECHO;
      [Pp]ortoe[ir]     ECHO;
      [Nn]etto 	        ECHO;
     [Bb]rutto 	        ECHO;
[^Gg][^r][Aa]uto        ECHO;
     [Mm]etazo  	ECHO;
      [Pp]iezo 	        ECHO;
    [Tt]rapezo          ECHO;
      [Bb]enzo	        ECHO;


          [Oo]erlikon 	ECHO;
            Boeing      ECHO;
        [Oo]boe 	ECHO;
         mandoein       ECHO;
         [Bb]oeuf       ECHO;
       [Ii]ndoeuro	ECHO;
            doebene     ECHO;
          [Oo]euvre     ECHO;
         [Gg]oethe	ECHO;
    [Dd]iarrhoea	ECHO;
            Joel	ECHO;
            Joe/{W}	ECHO;
         [Kk]oedukat 	ECHO;
       [KkCc]oeffi[cz]i ECHO;
         [Kk]oenzym 	ECHO;
       [KkCc]oexist 	ECHO;
         [Kk]oerzi 	ECHO;
           Aloe 	ECHO;
    [Oo]ldesloe	        ECHO;
          Oslo          ECHO;
         [Mm]oers/{W} 	ECHO;
       [Hh]omoeo        printf("%como",yytext[0]);
    [Hh]o[ml]oe 	ECHO;
         [Nn]oether 	ECHO;
         [Nn]oetik 	ECHO;
         [Nn]oetisch 	ECHO;
         [Pp]oesie 	ECHO;
         [Pp]oebene 	ECHO;
         [Pp]oe[mt]/[hirs] 	ECHO;
         [Pp]oe[mt][^a-z] ECHO;
       [Hh]eroen 	ECHO;
        [Pp]roenzy	ECHO;
         [Ss]oeben 	ECHO;
            Soest   	ECHO;
       [Tt]otoer	ECHO;
            Voest   	ECHO;
    [Pp]rotozoe 	ECHO;

[Mm][ai][ck]roe         ECHO;



A[eE]           printf("");
ae              printf("");
O[eE]           printf("");
oe              printf("");
U[eE]           printf("");
ue              printf("");

